#!/bin/sh

# collectLogs.sh
# SupportTool
#
# Created by Andy Tzebg on 2009/5/19.
# Copyright 2009 Trend Micro Incorporated. All rights reserved.

# Folder List
TMP_FOLDER="/tmp"
FOLDER_VAR_LOG_TM="/var/log/TrendMicro"
FOLDER_VAR_LOG_TM_CORE="$FOLDER_VAR_LOG_TM/TmccCore"
FOLDER_LIBS_LOG_TM="$HOME/Library/Logs/TrendMicro"
FOLDER_LIBS_LOG_TM_DEBUG="$FOLDER_LIBS_LOG_TM/Debug"
FOLDER_LIBS_LOG_TM_DEBUG_APP="$FOLDER_LIBS_LOG_TM_DEBUG/Application"
FOLDER_AU_LOG="/Library/Application Support/TrendMicro/common/lib/AUlib/AU_Data/AU_Log"
FOLDER_STARTUP_ITEM="/Library/StartupItems"
FOLDER_LAUNCH_AGENT="/Library/LaunchAgents"
FOLDER_LAUNCH_DAEMON="/Library/LaunchDaemons"
FOLDER_ICORE_ICRC_CDT="/Library/Application Support/TrendMicro/common/lib/CRC/cdtlog"
FOLDER_ICORE_ICRC_LOG="/Library/Application Support/TrendMicro/common/lib/CRC/icrc_diagnostic.log"
FOLDER_ICORE_DCE_REPORT="/Library/Application Support/TrendMicro/common/lib/DCE/report"
FOLDER_ICORE_DCE_DEBUG="/Library/Application Support/TrendMicro/common/lib/DCE/debug"

# TM Folder List
TM_FOLDER_SUPPORT="/Library/Application Support/TrendMicro"
TM_FOLDER_APP="/Applications/TrendMicro.localized"
TM_FOLDER_KEXT="/System/Library/TrendMicro"
TM_FOLDER_STARTUP_ITEM="$FOLDER_STARTUP_ITEM/iCoreService"

# Exclude List
SUPPORT_TOOL_LOG_FOLDER="$FOLDER_VAR_LOG_TM/SupportTool"

# Program List
PROGRAM_LIST="UIMgmt iTIS InstallerHelper TmLoginMgr iCoreStarter iCoreService iCoreService_wp iCoreService_av UpdateUtility SupportTool FBDaemon CollectorHelper"

# Configuration Files
TMPLUGIN_CONFIG="/Library/Application Support/TrendMicro/Plug-in/iTISPlugin.framework/Resources/TMPlugin.plist"
ICORE_WTP_CONFIG='/Library/Application\ Support/TrendMicro/common/conf/wp/*.conf.plist'
TMCC_MAC_CONFIG='/Library/Application\ Support/TrendMicro/common/conf/*.conf.plist'
TMCC_CORE_SVC_CONFIG="/Library/Application Support/TrendMicro/common/conf/iCoreService.conf.plist"
AUCFG_INI="/Library/Application Support/TrendMicro/common/lib/AUlib/aucfg.ini"
ITISTOOLBAR_CONFIG="/Library/Application Support/TrendMicro/TmToolbar/iTISToolbar.plist"
DCA_CONFIG="/Library/Application Support/TrendMicro/DCA/DCAManager.app/Contents/Resources/Config.plist"
DMR_CONFIG="/Library/Application Support/TrendMicro/DMR/DMRManager.app/Contents/Resources/Config.plist"
CORRIDOR_CONFIG="/Library/Application Support/TrendMicro/Plug-in/Corridor.framework/Resources/Corridor.plist"
CORRIDOR_CONFIG_BAK="/Library/Application Support/TrendMicro/Plug-in/Corridor.framework/Resources/Corridor.bak"
MULTI_PLIST_MERGE_CONFIG="/Library/Application Support/TrendMicro/TmccUpdate/multiPlistMerge.conf.plist"
AU_BLACKLIST_CONFIG="/Library/Application Support/TrendMicro/TmccUpdate/AUBlackList.plist"

# Log DB file
TMCC_DB="/Library/Application Support/TrendMicro/common/var/iCore.db"

# SystemConfiguration
# for Application Layer Filter
ALF_PLIST="/Library/Preferences/com.apple.alf.plist"
# for Power Saving
POWER_MANAGEMENT_PLIST="/Library/Preferences/SystemConfiguration/com.apple.PowerManagement.plist"
# for Automatically launch program list
LOGINWINDOW_PLIST="/Library/Preferences/loginwindow.plist"
LOGINITEMS_PLIST="/Library/Preferences/com.apple.loginitems.plist"


# Command
STPlistHandler="./STPlistHandler"

# UI Debug level keyPath
keyPathForMainUI="dicMainAppDebugConfig.i_DebugLogLevel"
keyPathForUIMgmt="dicUIMgmtDebugConfig.i_DebugLogLevel"
keyPathForCore="DebugLog.level"
keyPathForDCA="LogLevel"
keyPathForDMR="LogLevel"

declare -a logFolder
logFolderRoot=0
logFolderEnvironment=1
logFolderConfig=2
logFolderConfigUser=3
logFolderConfigSystem=4
logFolderConfigiTIS=5
logFolderLogs=6
logFolderLogsSystem=7
logFolderLogsSystemLibLog=8
logFolderLogsSystemVarLog=9
logFolderLogsSystemGlobalCrash=10
logFolderLogsSystemUserCrash=11
logFolderLogsSystemKernPanic=12
logFolderLogsiTIS=13
logFolderLogsiTISAULog=14
logFolderLogsiTISDBLog=15
logFolderLogsiTISVarLog=16
logFolderLogsiTISUserLog=17
logFolderLogsiCoreiCRCLog=18
logFolderLogsiCoreDCELog=19

logFolderLogsiTISToolbar=18

# Config for Debugging
CONF_COMPRESS=1

usage()
{
    echo "Usage $0 <prepare|wrapup> <DebugConfig_path> <UI_Level> [AU_Level] [iCORE_Level]" >&2
    echo "         <collect|collect_wo_compress> <collect_filename>" >&2
    exit 1;
}

createFolder()
{
    FOLDER="$1";

    if [ ! -z "$FOLDER" -a ! -d "$FOLDER" ]; then
        mkdir -p "$FOLDER"
        chmod 777 "$FOLDER"
    fi
}

# Turn On Debug Level
changeDebugLevel()
{
    if [ $# -lt 2 ]; then
        usage;
        return;
    fi

    DEBUGCONF="$1"
    UI_LEVEL="$2"
    AU_LEVEL="$3"
    CORE_LEVEL="$4"
    DCA_LEVEL="$5"
	DMR_LEVEL="$5"

    if [ ! -r "$DEBUGCONF" -o ! -e "$STPlistHandler" ]; then
        usage;
        return;
    fi

    # Change UI Debug Level
    $STPlistHandler write "$DEBUGCONF" "$keyPathForMainUI" -int $UI_LEVEL "$keyPathForUIMgmt" -int $UI_LEVEL

    # Change AU Debug Level
    if [ ! -z "$AU_LEVEL" ]; then
        sed -i'.bak' 's/^\(level\s*=\s*\).*$/\1'$AU_LEVEL'/' "$AUCFG_INI"
    fi

    # Change iCore Debug Level
    if [ ! -z "$CORE_LEVEL" ]; then
        cp -f "$TMCC_CORE_SVC_CONFIG" "$TMCC_CORE_SVC_CONFIG.org"
        $STPlistHandler write "$TMCC_CORE_SVC_CONFIG" "$keyPathForCore" -int $CORE_LEVEL
    fi

    # Change DCA Debug Level
    $STPlistHandler write "$DCA_CONFIG" "$keyPathForDCA" -string $DCA_LEVEL

	# Change DMR Debug Level
	$STPlistHandler write "$DMR_CONFIG" "$keyPathForDMR" -string $DMR_LEVEL
}

prepareEnvironment()
{
    createFolder $FOLDER_VAR_LOG_TM
    createFolder $FOLDER_VAR_LOG_TM_CORE
    createFolder $FOLDER_LIBS_LOG_TM
    createFolder $FOLDER_LIBS_LOG_TM_DEBUG
    createFolder $FOLDER_LIBS_LOG_TM_DEBUG_APP

    changeDebugLevel $*;

}

# Folder Hierarchical
#
# Environment/
# Config/
#   + User/
#   + System/
#   + iTIS/
#
# Logs/
#   + System/
#       + LibLog/
#       + VarLog/
#       + GlobalCrash/
#       + UserCrash/
#       + KernelPanic/
#
#   + iTIS/
#       + AULog/
#       + DBLog/
#       + VarLog/
#       + UserLog/
#
createCollectFolder()
{
    logFolder[$logFolderRoot]="$1"
    logFolder[$logFolderEnvironment]="${logFolder[$logFolderRoot]}/Environment"
    logFolder[$logFolderConfig]="${logFolder[$logFolderRoot]}/Config"
    logFolder[$logFolderConfigUser]="${logFolder[$logFolderConfig]}/User"
    logFolder[$logFolderConfigSystem]="${logFolder[$logFolderConfig]}/System"
    logFolder[$logFolderConfigiTIS]="${logFolder[$logFolderConfig]}/iTIS"
    logFolder[$logFolderLogs]="${logFolder[$logFolderRoot]}/Logs"
    logFolder[$logFolderLogsSystem]="${logFolder[$logFolderLogs]}/System"
    logFolder[$logFolderLogsSystemLibLog]="${logFolder[$logFolderLogsSystem]}/LibLog"
    logFolder[$logFolderLogsSystemVarLog]="${logFolder[$logFolderLogsSystem]}/VarLog"
    logFolder[$logFolderLogsSystemGlobalCrash]="${logFolder[$logFolderLogsSystem]}/GlobalCrash"
    logFolder[$logFolderLogsSystemUserCrash]="${logFolder[$logFolderLogsSystem]}/UserCrash"
    logFolder[$logFolderLogsSystemKernPanic]="${logFolder[$logFolderLogsSystem]}/KernPanic"
    logFolder[$logFolderLogsiTIS]="${logFolder[$logFolderLogs]}/iTIS"
    logFolder[$logFolderLogsiTISAULog]="${logFolder[$logFolderLogsiTIS]}/AULog"
    logFolder[$logFolderLogsiTISDBLog]="${logFolder[$logFolderLogsiTIS]}/DBLog"
    logFolder[$logFolderLogsiTISVarLog]="${logFolder[$logFolderLogsiTIS]}/VarLog"
    logFolder[$logFolderLogsiTISUserLog]="${logFolder[$logFolderLogsiTIS]}/UserLog"
    logFolder[$logFolderLogsiTISToolbar]="${logFolder[$logFolderLogsiTIS]}/Toolbar"
    logFolder[$logFolderLogsiCoreiCRCLog]="${logFolder[$logFolderLogsiTIS]}/iCoreiCRC"
    logFolder[$logFolderLogsiCoreDCELog]="${logFolder[$logFolderLogsiTIS]}/iCoreDCE"

    for i in ${logFolder[*]}; do
        mkdir -p $i
    done
}

collectFolder()
{
    if [ $# -lt 2 ]; then
        return;
    fi
    folder="$1"
    folderLog="$2"
    echo "ls -ld \"$folder\"" >> "$folderLog"
    ls -ld "$folder" >> "$folderLog" 2>/dev/null
    if [ $? -eq 0 ]; then
        echo "find \"$folder\"" >> "$folderLog"
        find "$folder" >> "$folderLog"
        ls -lR "$folder" >> "$folderLog"
    fi
}

collectLogs()
{
    if [ `dirname $1` = "." ]; then
        dst="`pwd -P`/$1"
    else
        dst="$1"
    fi
    if [ $CONF_COMPRESS -eq 1 ]; then
        logRootFolder="$TMP_FOLDER/`basename $dst .tgz`"
    else
        logRootFolder="$dst"
    fi

    # create folder hierarchical
    createCollectFolder $logRootFolder

    # collect environment information
    ps -avxww > "${logFolder[$logFolderEnvironment]}/process.log"
    kextstat > "${logFolder[$logFolderEnvironment]}/kextstat.log"
    ifconfig > "${logFolder[$logFolderEnvironment]}/ifconfig.log"
    netstat -rn > "${logFolder[$logFolderEnvironment]}/netstat.log"
    dmesg > "${logFolder[$logFolderEnvironment]}/dmesg.log"
    df > "${logFolder[$logFolderEnvironment]}/df.log"
    uname -a > "${logFolder[$logFolderEnvironment]}/uname.log"
    sw_vers > "${logFolder[$logFolderEnvironment]}/sw_vers.log"
    system_profiler > "${logFolder[$logFolderEnvironment]}/system_profiler.log"
    scutil --proxy > "${logFolder[$logFolderEnvironment]}/current_proxy.log"

    # collect the current folder content
    folderContent="${logFolder[$logFolderEnvironment]}/folder_content.log"
	
	# collect iTIS versions
	/Library/Application\ Support/TrendMicro/TmccMac/iCoreMgr -s get versions > "${logFolder[$logFolderEnvironment]}/iTISVersion.log"

    collectFolder "$TM_FOLDER_SUPPORT" "$folderContent"
    collectFolder "$TM_FOLDER_APP" "$folderContent"
    collectFolder "$TM_FOLDER_KEXT" "$folderContent"
    collectFolder "$TM_FOLDER_STARTUP_ITEM" "$folderContent"

    # collect system log, install.log, and kernel.log in /var/log
    cp /var/log/install.log "${logFolder[$logFolderLogsSystemVarLog]}" 2>/dev/null
    cp /var/log/system.log "${logFolder[$logFolderLogsSystemVarLog]}" 2>/dev/null
    cp /var/log/kernel.log "${logFolder[$logFolderLogsSystemVarLog]}" 2>/dev/null

    #collect iCore's kernel log
    log show --predicate 'eventMessage contains "TMCCFS"' > "${logFolder[$logFolderLogsSystemVarLog]}/TMCCFS.log"
    log show --predicate 'eventMessage contains "KERedirect"' > "${logFolder[$logFolderLogsSystemVarLog]}/KERedirect.log"

    console_dir="/Library/Logs/Console/$SUDO_UID/console.log"
    if [ -f "$console_dir" ]; then
        cp "$console_dir" "${logFolder[$logFolderLogsSystemLibLog]}"
    fi

    # collect crash/hang report
    for program in [ $PROGRAM_LIST ]; do
        cp /Library/Logs/CrashReporter/${program}_* "${logFolder[$logFolderLogsSystemGlobalCrash]}" 2>/dev/null
        cp $HOME/Library/Logs/CrashReporter/${program}_* "${logFolder[$logFolderLogsSystemUserCrash]}" 2>/dev/null
        cp /Library/Logs/CrashReporter/${program}.crash.log "${logFolder[$logFolderLogsSystemGlobalCrash]}" 2>/dev/null
        cp $HOME/Library/Logs/CrashReporter/${program}.crash.log "${logFolder[$logFolderLogsSystemUserCrash]}" 2>/dev/null
		
        cp -R /Library/Logs/HangReporter/${program} "${logFolder[$logFolderLogsSystemGlobalCrash]}" 2>/dev/null
        cp -R $HOME/Library/Logs/HangReporter/${program} "${logFolder[$logFolderLogsSystemUserCrash]}" 2>/dev/null

        cp -R /Library/Logs/PanicReporter/* "${logFolder[$logFolderLogsSystemKernPanic]}" 2>/dev/null
        cp /Library/Logs/DiagnosticReports/Kernel_* "${logFolder[$logFolderLogsSystemKernPanic]}" 2>/dev/null
		
		cp /Library/Logs/DiagnosticReports/${program}_* "${logFolder[$logFolderLogsSystemGlobalCrash]}" 2>/dev/null
        cp $HOME/Library/Logs/DiagnosticReports/${program}_* "${logFolder[$logFolderLogsSystemUserCrash]}" 2>/dev/null

    done

    # collect iTIS log in /var/log
    pushd "$FOLDER_VAR_LOG_TM" > /dev/null
    for file in `find $FOLDER_VAR_LOG_TM -maxdepth 1 -not -name SupportTool`; do
        if [ $file = $FOLDER_VAR_LOG_TM ]; then
            continue;
        fi
        cp -R "$file" "${logFolder[$logFolderLogsiTISVarLog]}"
    done
    popd > /dev/null

    # collect iTIS log in $HOME/Library/Logs/TrendMicro
    cp -R $FOLDER_LIBS_LOG_TM "${logFolder[$logFolderLogsiTISUserLog]}"

    # collect AU log
    if [ -d "$FOLDER_AU_LOG" ]; then
        cp -R "$FOLDER_AU_LOG" "${logFolder[$logFolderLogsiTISAULog]}"
    fi

    # collect iCore iCRC log
    if [ -d "$FOLDER_ICORE_ICRC_CDT" ]; then
    cp -R "$FOLDER_ICORE_ICRC_CDT" "${logFolder[$logFolderLogsiCoreiCRCLog]}"
    fi
    if [ -e "$FOLDER_ICORE_ICRC_LOG" ]; then
    cp -R "$FOLDER_ICORE_ICRC_LOG" "${logFolder[$logFolderLogsiCoreiCRCLog]}"
    fi

    # collect iCore DCE log
    if [ -d "$FOLDER_ICORE_DCE_REPORT" ]; then
    cp -R "$FOLDER_ICORE_DCE_REPORT" "${logFolder[$logFolderLogsiCoreDCELog]}"
    fi
    if [ -d "$FOLDER_ICORE_DCE_DEBUG" ]; then
    cp -R "$FOLDER_ICORE_DCE_DEBUG" "${logFolder[$logFolderLogsiCoreDCELog]}"
    fi

    # collect DB log
    cp -R "$TMCC_DB" "${logFolder[$logFolderLogsiTISDBLog]}"

    # export DB to csv files
    /usr/bin/sqlite3 "$TMCC_DB" <<SQL_END
.headers on
.mode csv
.output "${logFolder[$logFolderLogsiTISDBLog]}/au.csv"
SELECT id, strftime("%m-%d-%Y %H:%M:%S", time, 'unixepoch') as utc_time, strftime("%m-%d-%Y %H:%M:%S", time, 'unixepoch', 'localtime') as local_time, component, result, old_version, new_version FROM au;
.output "${logFolder[$logFolderLogsiTISDBLog]}/category.csv"
SELECT id, strftime("%m-%d-%Y %H:%M:%S", time, 'unixepoch') as utc_time, strftime("%m-%d-%Y %H:%M:%S", time, 'unixepoch', 'localtime') as local_time, category, subcategory, score, url FROM category;
.output "${logFolder[$logFolderLogsiTISDBLog]}/fw.csv"
SELECT id, strftime("%m-%d-%Y %H:%M:%S", time, 'unixepoch') as utc_time, strftime("%m-%d-%Y %H:%M:%S", time, 'unixepoch', 'localtime') as local_time, rule_index, detail FROM fw;
.output "${logFolder[$logFolderLogsiTISDBLog]}/malware.csv"
SELECT id, strftime("%m-%d-%Y %H:%M:%S", time, 'unixepoch') as utc_time, strftime("%m-%d-%Y %H:%M:%S", time, 'unixepoch', 'localtime') as local_time, scan_type, action, threat_name, file FROM malware;
.output "${logFolder[$logFolderLogsiTISDBLog]}/quarantine.csv"
SELECT id, strftime("%m-%d-%Y %H:%M:%S", time, 'unixepoch') as utc_time, strftime("%m-%d-%Y %H:%M:%S", time, 'unixepoch', 'localtime') as local_time, gid, uid, mode, original_file, quarantined_file FROM quarantine;
.output "${logFolder[$logFolderLogsiTISDBLog]}/wtp.csv"
SELECT id, strftime("%m-%d-%Y %H:%M:%S", time, 'unixepoch') as utc_time, strftime("%m-%d-%Y %H:%M:%S", time, 'unixepoch', 'localtime') as local_time, level, score, url FROM wtp;
.output "${logFolder[$logFolderLogsiTISDBLog]}/foldershield.csv"
SELECT id, strftime("%m-%d-%Y %H:%M:%S", time, 'unixepoch') as utc_time, strftime("%m-%d-%Y %H:%M:%S", time, 'unixepoch', 'localtime') as local_time, file, process, operation,signature,type FROM folder_shield;
SQL_END

    # collect system configuration files
    if [ -r "$ALF_PLIST" ]; then
        cp "$ALF_PLIST" "${logFolder[$logFolderConfigSystem]}"
    fi
    if [ -r "$POWER_MANAGEMENT_PLIST" ]; then
        cp "$POWER_MANAGEMENT_PLIST" "${logFolder[$logFolderConfigSystem]}"
    fi
    if [ -r "$LOGINWINDOW_PLIST" ]; then
        cp "$LOGINWINDOW_PLIST" "${logFolder[$logFolderConfigSystem]}"
    fi
    if [ -r "${HOME}$LOGINWINDOW_PLIST" ]; then
        cp "${HOME}$LOGINWINDOW_PLIST" "${logFolder[$logFolderConfigUser]}"
    fi

    if [ -r "$LOGINITEMS_PLIST" ]; then
        cp "$LOGINITEMS_PLIST" "${logFolder[$logFolderConfigSystem]}"
    fi

    if [ -r "${HOME}$GLOBAL_LOGINITEMS_PLIST" ]; then
        cp "${HOME}$LOGINITEMS_PLIST" "${logFolder[$logFolderConfigUser]}"
    fi

    # collect system launch agents
    cp -Rf "$FOLDER_LAUNCH_AGENT" "${logFolder[$logFolderConfigSystem]}"
    cp -Rf "$FOLDER_LAUNCH_DAEMON" "${logFolder[$logFolderConfigSystem]}"

    ipfw show > "${logFolder[$logFolderConfigSystem]}/ipfw.log"
	
    # collect itis configuration files
    cp "$TMPLUGIN_CONFIG" "${logFolder[$logFolderConfigiTIS]}"
    #cp "$ICORE_WTP_CONFIG" "${logFolder[$logFolderConfigiTIS]}"
	#cp "$TMCC_MAC_CONFIG" "${logFolder[$logFolderConfigiTIS]}"
	cp /Library/Application\ Support/TrendMicro/common/conf/wp/*.conf.plist "${logFolder[$logFolderConfigiTIS]}"
	cp /Library/Application\ Support/TrendMicro/common/conf/*.conf.plist "${logFolder[$logFolderConfigiTIS]}"
	cp /Library/Application\ Support/TrendMicro/TmccMac/UIMgmt.app/Contents/Info.plist "${logFolder[$logFolderConfigiTIS]}/UIMgmt_Info.plist"

    cp "$CORRIDOR_CONFIG" "${logFolder[$logFolderConfigiTIS]}"
    cp "$CORRIDOR_CONFIG_BAK" "${logFolder[$logFolderConfigiTIS]}"
    cp "$MULTI_PLIST_MERGE_CONFIG" "${logFolder[$logFolderConfigiTIS]}"
    cp "$AU_BLACKLIST_CONFIG" "${logFolder[$logFolderConfigiTIS]}"
    
	# collect AU config file
	cp "$AUCFG_INI" "${logFolder[$logFolderConfigiTIS]}"

    # begin collect information about toolbar
	# iTISToolbar.plist
	cp "$ITISTOOLBAR_CONFIG" "${logFolder[$logFolderConfigiTIS]}"

	# collection browser info
    ## not work if mlfind db is not created.
    #collect system language
    echo LANG=${LANG} >> "${logFolder[$logFolderLogsiTISToolbar]}/BrowserInfo.log"
    PLIST_BUDDY="/usr/libexec/PlistBuddy"
    for BrowserID in com.google.Chrome org.mozilla.firefox com.apple.Safari; do
        OLD_IFS=$IFS
        IFS=$'\n'
        if [ -e "$PLIST_BUDDY" ]; then
            for Browser in $(mdfind "kMDItemCFBundleIdentifier == $BrowserID")
            do
                echo "$Browser"
                VERSION=$($PLIST_BUDDY -c 'Print :CFBundleShortVersionString' "$Browser"/Contents/Info.plist | cut -d "." -f1)
                echo Version of $Browser: $VERSION >> "${logFolder[$logFolderLogsiTISToolbar]}/BrowserInfo.log"
                _Browser=${Browser:1}
                cp "$Browser"/Contents/Info.plist "${logFolder[$logFolderLogsiTISToolbar]}/${_Browser//\//.}.Info.plist"
            done
        fi
        IFS=$OLD_IFS
    done
    
    #collect login user's language
    for u in $(users); do
        echo The languages of $u is >> "${logFolder[$logFolderLogsiTISToolbar]}/BrowserInfo.log"
        sudo -u $u defaults read .GlobalPreferences AppleLanguages >> "${logFolder[$logFolderLogsiTISToolbar]}/BrowserInfo.log"
    done

    # collect firefox extension
    FirefoxExtPath="/Library/Application Support/Mozilla/Extensions/{ec8030f7-c20a-464f-9b0e-13a3a9e97384}"
    mkdir "${logFolder[$logFolderLogsiTISToolbar]}/Firefox"
    cp -rf "${FirefoxExtPath}" "${logFolder[$logFolderLogsiTISToolbar]}/Firefox"
    for app in `mdfind 'kMDItemCFBundleIdentifier == org.mozilla.firefox'` ;  do
        ls -Rl "$app" >> "${logFolder[$logFolderLogsiTISToolbar]}/BrowserInfo.log"
    done

    # collect chrome extension configurateion file
    ChromeExtCfgPath="/Library/Application Support/Google/Chrome/External Extensions/external_extensions.json"
    mkdir "${logFolder[$logFolderLogsiTISToolbar]}/Chrome"
    cp "${ChromeExtCfgPath}" "${logFolder[$logFolderLogsiTISToolbar]}/Chrome"
    # collect safari extension
    SafariExtPath="Library/Safari/Extensions"
    OLD_IFS=$IFS
    IFS=$'\n'
    ALL_USERS="$(find /Users -maxdepth 1 -type d| grep -v "^/Users$" |grep -v "Shared" | grep -v "Deleted*")"
    for USER in $ALL_USERS;do
        USER_NAME="$(echo "$USER" | cut -d"/" -f3)"
        USER_EXT_PATH="$USER/$SafariExtPath"
        mkdir -p "${logFolder[$logFolderLogsiTISToolbar]}/Safari/$USER_NAME"
        cp -rf $USER_EXT_PATH  "${logFolder[$logFolderLogsiTISToolbar]}/Safari/$USER_NAME"
    done
    IFS=$OLD_IFS
    # end collect information about toolbar

    if [ $CONF_COMPRESS -ne 1 ]; then
        if [ ! -z "$SUDO_UID" ]; then
            chown -R $SUDO_UID "$TMP_FOLDER"
        fi
        echo "Logs are stored in $TMP_FOLDER" >&2
        return;
    fi

    dst_folder=`dirname $dst`
    folderName=`basename $dst .tgz`

    if [ ! -d "$dst_folder" ]; then
        mkdir -p "$dst_folder";
    fi
    pushd "$TMP_FOLDER"
    tar -zcvf "$dst" "$folderName"
    rm -rf "$logRootFolder"

    if [ ! -z "$SUDO_UID" ]; then
        chown $SUDO_UID "$dst"
    fi
}

wrapupEnvironment()
{
    changeDebugLevel $*
}

OPT="$1";
shift 1;
RET=0;
case "$OPT" in
    prepare)
        prepareEnvironment $*;
        ;;

    collect)
        if [ -z "$1" ]; then
            usage;
        fi
        collectLogs "$1";
        ;;

    collect_wo_compress)
        if [ -z "$1" ]; then
            usage;
        fi
        CONF_COMPRESS=0
        collectLogs "$1";
        ;;

    wrapup)
        wrapupEnvironment $*;
        ;;

    *)
        usage;
        ;;

esac

exit $RET;
